@@ -1,29 +1,34 @@
+"""This module implements a SLAM mapping skill.
+"""
 from typing import Union
 
-from misty2py.basic_skills.cancel_skills import cancel_skills
-from misty2py.utils.messages import message_parser
 from misty2py.utils.utils import get_misty
 from pynput import keyboard
 
 misty = get_misty()
 
 INFO_KEY = keyboard.KeyCode.from_char("i")
+"""The key to print for SLAM information."""
 START_KEY = keyboard.Key.home
+"""The key to print to start exploring."""
 TERM_KEY = keyboard.Key.esc
+"""The key to print to terminate the skill."""
 HELP_KEY = keyboard.KeyCode.from_char("h")
+"""The key to print for help information."""
 
 
 def get_slam_info():
-    enabled = misty.get_info("slam_enabled")
-    if enabled.get("result"):
+    """Obtains and prints the SLAM status."""
+    enabled = misty.get_info("slam_enabled").parse_to_dict().get("rest_response", {})
+    if enabled.get("success"):
         print("SLAM enabled.")
     else:
         print("SLAM disabled.")
         return
 
-    status = misty.get_info("slam_status")
-    result = status.get("status")
-    if result == "Success":
+    status = misty.get_info("slam_status").parse_to_dict().get("rest_response", {})
+    result = status.get("success")
+    if result:
         info = status.get("result")
         if info:
             print(f"SLAM status: {info}")
@@ -32,6 +37,7 @@ def get_slam_info():
 
 
 def get_instructions():
+    """Prints the instructions."""
     print(
         f"\n>>> INSTRUCTIONS <<<\n \
     - press {START_KEY} to start exploring (SLAM mapping) \n \
@@ -41,17 +47,25 @@ def get_instructions():
     )
 
 
-def handle_press(key: Union[keyboard.Key, keyboard.KeyCode]):
-    print(f"{key} registered.")
-    stat = misty.get_info("slam_enabled")
+def handle_press(key: Union[keyboard.Key, keyboard.KeyCode]) -> bool:
+    """Handles responses to pressing a key.
 
-    if stat.get("status") == "Failed":
+    Args:
+        key (Union[keyboard.Key, keyboard.KeyCode]): The pressed key.
+
+    Returns:
+        bool: `False` upon termination.
+    """
+    print(f"{key} registered.")
+    stat = misty.get_info("slam_enabled").parse_to_dict().get("rest_response", {})
+
+    if not stat.get("success"):
         print("SLAM disabled, terminating the program.")
         return False
 
     if key == START_KEY:
-        resp = misty.perform_action("slam_mapping_start")
-        print(message_parser(resp))
+        resp = misty.perform_action("slam_mapping_start").parse_to_dict()
+        print(resp)
         print(f"{key} processed.")
 
     elif key == INFO_KEY:
@@ -63,18 +77,19 @@ def handle_press(key: Union[keyboard.Key, keyboard.KeyCode]):
         print(f"{key} processed.")
 
     elif key == TERM_KEY:
-        resp = misty.perform_action("slam_mapping_stop")
-        print(message_parser(resp))
+        resp = misty.perform_action("slam_mapping_stop").parse_to_dict()
+        print(resp)
         print(f"{key} processed.")
         return False
 
 
 def handle_release(key: keyboard.Key):
+    """The method required by the keyboard package but not used in this skill."""
     pass
 
 
 def explore():
-    cancel_skills(misty)
+    """Attempts to perform SLAM mapping."""
     get_instructions()
     with keyboard.Listener(
         on_press=handle_press, on_release=handle_release
